﻿namespace UltraTimeLineWithCheckBoxes
{
    using System;
    using System.Drawing;
    using System.Windows.Forms;
    using System.Collections.Generic;

    using Infragistics.Win.UltraWinSchedule;
    using System.Data;

    public partial class Form1 : Form
    {
        private Dictionary<Owner, OwnerState> initialData = new Dictionary<Owner, OwnerState>();
        private int ownersCount = 10;
        private MyCreation myCreation;

        public Form1()
        {
            this.InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraCalendarInfo1.SelectedDateRanges.Add(DateTime.Now, DateTime.Now.AddDays(1));
            myCreation = new MyCreation(initialData);
            this.ultraDayView1.CreationFilter = myCreation;

            Point checkBoxLocation = new Point(5, 2);

            for (int i = 0; i < this.ownersCount; i++)
            {
                Owner owner = ultraCalendarInfo1.Owners.Add(string.Format("Owner {0}", i));
                CheckBox checkBox = new CheckBox();
                checkBox.Name = owner.Key;
                checkBox.Text = string.Format("Show {0}", owner.Key);
                checkBox.Location = checkBoxLocation;
                checkBoxLocation.Offset(0, 23);
                this.panel1.Controls.Add(checkBox);
                Binding binding = checkBox.DataBindings.Add("Checked", owner, "Visible");
                binding.DataSourceUpdateMode = DataSourceUpdateMode.OnPropertyChanged;
                binding.ControlUpdateMode = ControlUpdateMode.OnPropertyChanged;

                // Set check state of all CheckBoxes with today date to checked
                Dictionary<DateTime, State> state = new Dictionary<DateTime, State>();
                state[DateTime.Today] = new State(true, true);
                OwnerState ownerState = new OwnerState(true);
                ownerState.State = state;
                this.myCreation.OwnerState.Add(owner, ownerState);
            }

            this.ultraDayView1.PreferredInViewColumnCount = 3;

            this.ultraCalendarInfo1.Owners["{unassigned_owner}"].Visible = false;
            ((MyCreation)ultraDayView1.CreationFilter).DayHeaderCheck += this.Form1_DayHeaderCheck;

            ultraDayView1.DrawFilter = new MyDraw();

            this.ultraGrid1.DataSource = this.GetGridData();
        }

        private DataTable GetGridData()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("Owner_name", typeof(string));
            dt.Columns.Add("Checked_ind", typeof(bool));
            dt.Columns.Add("IsEnabled", typeof(bool));

            foreach (Owner owner in this.ultraCalendarInfo1.Owners)
            {
                dt.Rows.Add(owner.Key, false, true);
            }

            return dt;
        }

        private void Form1_DayHeaderCheck(object sender, DayHeaderCheckBoxArg e)
        {
            CheckBox cb = sender as CheckBox;
            if (cb != null)
            {
                MessageBox.Show(string.Format("Checkbox for {0} on {1} clicked {2}", e.Owner.Key, e.Date.ToShortDateString(), cb.Name));
            }
        }

        private void ultraGrid1_CellChange(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            if (e.Cell.Column.Header.Caption == "Checked_ind")
            {
                bool isChecked = bool.Parse(e.Cell.Text);
                string ownerKey = e.Cell.Row.Cells["Owner_name"].Text;
                Owner owner = this.ultraCalendarInfo1.Owners[ownerKey];

                foreach (KeyValuePair<DateTime, State> state in this.myCreation.OwnerState[owner].State)
                {
                    state.Value.Complete = isChecked;
                    state.Value.Draft = isChecked;
                }

                this.ultraDayView1.Invalidate();
            }

            if (e.Cell.Column.Header.Caption == "IsEnabled")
            {
                bool isChecked = bool.Parse(e.Cell.Text);
                string ownerKey = e.Cell.Row.Cells["Owner_name"].Text;
                Owner owner = this.ultraCalendarInfo1.Owners[ownerKey];

                this.myCreation.OwnerState[owner].IsEnabled = isChecked;

                this.ultraDayView1.Invalidate();
            }
        }
    }
}